# perl upfilt.pl <file>.html
# 
# Pre-process HTML files from Nita's Urdu Poetry Site
# http://www.urdupoetry.com to covert them to .s files that can be 
# converted by ITRANS, itxsed.pl, etc.
# Special: in the input text in urdu, Kh is changed to K (ka-dot of ITRANS).
# Also: B -> b, Z -> z
#
# 2015: noticed that this still leaves a lot of HTML lines in the .s files.
# Before \startsong and after \endsong
# So need to run some scripts after this to clean that up - it contains many hrefs etc.
#  for i in [abc]/*.s
#  do
#  sed -n '/\\startsong/,$p' $i | sed '/\\endsong/q' > fixed.s
#  /bin/mv fixed.s $i
#  done
#
#
#-------------------------------------------------------------------------
$startindian = 0;
$endindian = 0;

$lastlinewasempty = 0;
$contrib = "";
$singer = "";

while (<>) {
    chop($line = $_);

    # erase certain kinds of comments/lines from the .html files
    $line =~ s:<HTML>|</HTML>::g;
    $line =~ s:<HEAD>|</HEAD>::g;
    $line =~ s:<CENTER>|</CENTER>::g;
    $line =~ s:<BODY .*>|</BODY>::g;
    $line =~ s:<A .*>|</A>::g;

    $line =~ s:<BR>|<P>::g;

    # trim space at end
    $line =~ s/\s+$//;

    next if $line eq "" && !$startindian;
    next if $line eq "" && $lastlinewasempty;

    # <I> Contributed by: Rajeev M. Patel </I>
    # <I> Additions by: Rajeev M. Patel </I>
    if ($line =~ /Contributed|Additions/) {
	$line =~ s:\s*<I>\s*|\s*</I>\s*::g;
        $contrib = $contrib . "% ". $line ."\n";
	next;
    }
    if ($line =~ /<TITLE>/) {
	$singer = $line;
	$singer =~ s:<TITLE>|</TITLE>::g;
	$singer =~ s/\s+$//; # remove space at end
	$singer =~ s/^\s+//; # remove space at start
	next;
    }


    # tricky portion: determine where the urdu portion starts/ends
    # examples:
    # <HR WIDTH = 60%>
    # <IMG SRC="/pictures/icons/lines/wave_thin_gray_1.gif">
    if ($line =~ /wave_thin_gray_1.gif|HR WIDTH/) {
	if ($startindian) {
	    $endindian = 1;
	    last; # skip all following lines
	} else {
	    $startindian = 1;
	    print "\\singers{$singer}\n" if $singer;
	    print "$contrib" if $contrib;
	    print "\\printtitle\n#indian\n";
	    next;
	}
    }

    if ($startindian) {
        $line =~ s/Kh/K/g;
	#ex: Khaak ho jaae.nge ham tum ko Khabar hone tak<BR>
        $line =~ s/B/b/g;
        $line =~ s/Z/z/g;
        $line =~ s/F/f/g;
        $line =~ s/Y/y/g;
    }

    $line =~ s/<B>(.*)$/\\stitle{\1}/ if !$startindian;
    #ex: <B> vo baate.n terii vo fasaane tere <BR> </B>

    $line =~ s/<I> (.*) <.*/\\lyrics{\1}/ if !$startindian;
    #ex: <I> Abdul Hamid 'Adam' <BR> </I> 

    $line =~ s/(<I> Qatah.*)/##\1##/ if $startindian;
    $line =~ s/(<I> Gazal.*)/##\1##/ if $startindian;
    #ex: <I> Qatah: </I> <BR>
    #ex: <I> Gazal: </I> <BR>

    # lines with [ .... ] should be comments
    # [taGaaful = neglect] <BR>
    $line =~ s/(\s*\[)/%\1/;

    if ($line =~ /\\stitle/) {
        print "\n\\startsong\n";
    }

    $line =~ s:<B>|</B>|<I>|</I>::g; #any remaining B I not needed

    #spaces at start and end in { }, remove
    $line =~ s/\s+}/}/;
    $line =~ s/{\s+/{/;

    print "$line\n";

    $lastlinewasempty = $line eq "" ? 1 : 0;
} # while (<>)

print "#endindian\n\\endsong\n";

# print some lines that follow
if ($startindian && $endindian) {
    while (<>) {
	chop($line = $_);

	# <A HREF = "./LstBA.html"> Begum Akhtar Page </A> <BR>
	if ($line =~ /HREF = "[\w\.]/) {
	    print "$line\n";
	}
    }
}
#-------------------------------------------------------------------------
#-------------------------------------------------------------------------
